@@ -121,6 +121,25 @@ class Entry(EntryQueryable):
         self.entry_param['include_fallback'] = 'true'
         return self
 
+    def include_embedded_items(self):
+        """include_embedded_items instance of Entry
+        include_embedded_objects (Entries and Assets) along with entry/entries details.
+        :return: Entry, so we can chain the call
+
+        ----------------------------
+        Example:
+
+            >>> import contentstack
+            >>> stack = contentstack.Stack('api_key', 'delivery_token', 'environment')
+            >>> content_type = stack.content_type('content_type_uid')
+            >>> entry = content_type.entry(uid='entry_uid')
+            >>> entry = entry.include_embedded_items()
+            >>> result = entry.fetch()
+        ----------------------------
+        """
+        self.entry_param['include_embedded_items[]'] = "BASE"
+        return self
+
     def __get_base_url(self):
         if None in (self.http_instance, self.content_type_id, self.entry_uid):
             raise KeyError('Provide valid http_instance, content_type_uid or entry_uid')
